@@ -3,7 +3,7 @@ package Devel::Platform::Match;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-08'; # DATE
 our $DIST = 'Devel-Platform-Match'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -383,7 +383,7 @@ Devel::Platform::Match - Match platform information with platform specification
 
 =head1 VERSION
 
-This document describes version 0.002 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
+This document describes version 0.003 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
 
 =head1 SYNOPSIS
 
@@ -393,8 +393,9 @@ This document describes version 0.002 of Devel::Platform::Match (from Perl distr
  my $envres = match_platform("osflag=linux"); # -> [200, "OK", 1]
  my $envres = match_platform("linux32");      # -> [200, "OK", 0] # linux32 is alias for "osflag=linux archname=x86"; archname doesn't match
  my $envres = match_platform("win64");        # -> [200, "OK", 0] # win64 is alias for "osflag=Win32 archname=x86_64"; osflag doesn't match
- my $envres = match_platform("osflag=linux oslabel=~/Debian|Ubuntu|Mint/"); # -> [200, "OK", 1]
- my $envres = match_platform("osflag=linux, oslabel=~/Debian|Ubuntu|Mint/, osvers >= 21"); # -> [200, "OK", 0] ; # osvers doesn't match
+ my $envres = match_platform("osflag=linux oslabel=~/Debian|Ubuntu|Mint/");                 # -> [200, "OK", 1]
+ my $envres = match_platform("osflag=linux, oslabel=~/Debian|Ubuntu|Mint/, osvers >= 21"); # -> [200, "OK", 0] # osvers doesn't match
+ my $envres = match_platform("foo");                                                       # -> [412, "Invalid syntax in platform spec 'foo'"]
 
 =head1 DESCRIPTION
 
@@ -409,10 +410,13 @@ Platform specification is a whitespace- (or comma-) separated list of clauses.
 
 Each clause is of the form: C<key> C<op> C<literal>.
 
-Key is any key of the hash returned by L<Devel::Platform::Info>.
+C<key> is any key of the hash returned by L<Devel::Platform::Info>.
 
 C<op> is operator supported by L<Data::CSel>.
 
+C<literal> is a bareword number or word, or a quoted string. See Data::CSel for
+more information.
+
 A platform specification with zero clauses (C<"">) will match all platforms.
 
 For convenience, some aliases will be coerced into a proper platform
@@ -427,16 +431,21 @@ specification first:
     "win64"        => "osflag=Win32 archname=x86_64",
     "all"          => "",
 
-Some examples of platform specifications:
+Some examples of valid and invalid platform specifications:
 
- specification                 parse result                                            note
- -------------                 ------------                                            ----
- linux32                       [["osflag","=","linux"], ["archname","=","x86"]]        coerced to "osflag=linux archname=x86" before parsing
- oslabel=Ubuntu                [["oslabel","=","Ubuntu"]]
- osflag=linux oslabel=Ubuntu   [["osflag","=","linux"], ["oslabel","=","Ubuntu"]]
- oslabel=~/Debian|Ubuntu/      [["oslabel","=~",qr/Debian|Ubuntu/]]
- is32bit=1                     [["is32bit","=",1]]                                     any 32bit platform
- is32bit is true               [["is32bit","=",1]]                                     any 64bit platform
+ specification                  parse result                                            note
+ -------------                  ------------                                            ----
+ linux32                        [["osflag","=","linux"], ["archname","=","x86"]]        coerced to "osflag=linux archname=x86" before parsing
+ oslabel=Ubuntu                 [["oslabel","=","Ubuntu"]]
+ osflag=linux oslabel=Ubuntu    [["osflag","=","linux"], ["oslabel","=","Ubuntu"]]
+ osflag=linux, oslabel=Ubuntu   [["osflag","=","linux"], ["oslabel","=","Ubuntu"]]      either whitespace or comma is okay as separator
+ oslabel=~/Debian|Ubuntu/       [["oslabel","=~",qr/Debian|Ubuntu/]]
+ is32bit=1                      [["is32bit","=",1]]                                     any 32bit platform
+ is32bit is true                [["is32bit","is",1]]                                    any 64bit platform
+ "" (empty string)              []                                                      no clauses, will match any platform info
+ foo                            undef                                                   invalid syntax, unknown alias
+ oslabel=Ubuntu,oslabel=Debian  [["osflag","=","Ubuntu"], ["osflag","=","Debian"]]      valid, but won't match any platform
+ archname=amd64                 [["archname","=","amd64"]]                              Will match platform info {archname=>"x86_64"} because of normalization
 
 =head1 PLATFORM MATCHING
 
